@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.bcel.verifier.structurals;
 
@@ -78,11 +80,10 @@ public class ControlFlowGraph {
          * Creates an InstructionHandleImpl object from an InstructionHandle. Creation of one per InstructionHandle suffices.
          * Don't create more.
          */
-        public InstructionContextImpl(final InstructionHandle inst) {
+        InstructionContextImpl(final InstructionHandle inst) {
             if (inst == null) {
                 throw new AssertionViolatedException("Cannot instantiate InstructionContextImpl from NULL.");
             }
-
             instruction = inst;
             inFrames = new HashMap<>();
             outFrames = new HashMap<>();
@@ -160,7 +161,7 @@ public class ControlFlowGraph {
          * calculates the "outgoing" frame situation. Returns: True iff the "incoming" frame situation changed after merging
          * with "inFrame". The execPreds ArrayList must contain the InstructionContext objects executed so far in the correct
          * order. This is just one execution path [out of many]. This is needed to correctly "merge" in the special case of a
-         * RET's successor. <B>The InstConstraintVisitor and ExecutionVisitor instances must be set up correctly.</B>
+         * RET's successor. <strong>The InstConstraintVisitor and ExecutionVisitor instances must be set up correctly.</strong>
          *
          * @return true - if and only if the "outgoing" frame situation changed from the one before execute()ing.
          */
@@ -247,12 +248,8 @@ public class ControlFlowGraph {
 
         @Override
         public Frame getInFrame() {
-            Frame org;
-
             final InstructionContext jsr = lastExecutionJSR();
-
-            org = inFrames.get(jsr);
-
+            final Frame org = inFrames.get(jsr);
             if (org == null) {
                 throw new AssertionViolatedException("inFrame not set! This:\n" + this + "\nInFrames: '" + inFrames + "'.");
             }
@@ -270,16 +267,11 @@ public class ControlFlowGraph {
         @Override
         public Frame getOutFrame(final ArrayList<InstructionContext> execChain) {
             executionPredecessors = execChain;
-
-            Frame org;
-
             final InstructionContext jsr = lastExecutionJSR();
-
-            org = outFrames.get(jsr);
-
+            final Frame org = outFrames.get(jsr);
             if (org == null) {
                 throw new AssertionViolatedException(
-                    "outFrame not set! This:\n" + this + "\nExecutionChain: " + getExecutionChain() + "\nOutFrames: '" + outFrames + "'.");
+                        "outFrame not set! This:\n" + this + "\nExecutionChain: " + getExecutionChain() + "\nOutFrames: '" + outFrames + "'.");
             }
             return org.getClone();
         }
@@ -296,7 +288,7 @@ public class ControlFlowGraph {
 
         /**
          * Returns the InstructionContextImpl with an JSR/JSR_W that was last in the ExecutionChain, without a corresponding
-         * RET, i.e. we were called by this one. Returns null if we were called from the top level.
+         * RET, for example we were called by this one. Returns null if we were called from the top level.
          */
         private InstructionContextImpl lastExecutionJSR() {
 
@@ -349,7 +341,7 @@ public class ControlFlowGraph {
          */
         @Override
         public String toString() {
-            // TODO: Put information in the brackets, e.g.
+            // TODO: Put information in the brackets, for example
             // Is this an ExceptionHandler? Is this a RET? Is this the start of
             // a subroutine?
             return getInstruction().toString(false) + "\t[InstructionContext]";
@@ -372,7 +364,7 @@ public class ControlFlowGraph {
     /**
      * A Control Flow Graph; with additional JustIce checks
      *
-     * @param methodGen the method generator instance
+     * @param methodGen the method generator instance.
      */
     public ControlFlowGraph(final MethodGen methodGen) {
         this(methodGen, true);
@@ -381,8 +373,8 @@ public class ControlFlowGraph {
     /**
      * A Control Flow Graph.
      *
-     * @param methodGen the method generator instance
-     * @param enableJustIceCheck if true, additional JustIce checks are performed
+     * @param methodGen the method generator instance.
+     * @param enableJustIceCheck if true, additional JustIce checks are performed.
      * @since 6.0
      */
     public ControlFlowGraph(final MethodGen methodGen, final boolean enableJustIceCheck) {
@@ -399,6 +391,9 @@ public class ControlFlowGraph {
 
     /**
      * Returns the InstructionContext of a given instruction.
+     *
+     * @param inst the instruction handle.
+     * @return the InstructionContext of the given instruction.
      */
     public InstructionContext contextOf(final InstructionHandle inst) {
         final InstructionContext ic = instructionContexts.get(inst);
@@ -410,6 +405,9 @@ public class ControlFlowGraph {
 
     /**
      * Returns the InstructionContext[] of a given InstructionHandle[], in a naturally ordered manner.
+     *
+     * @param insts the instruction handles.
+     * @return the InstructionContext array of the given instruction handles.
      */
     public InstructionContext[] contextsOf(final InstructionHandle[] insts) {
         final InstructionContext[] ret = new InstructionContext[insts.length];
@@ -419,7 +417,9 @@ public class ControlFlowGraph {
 
     /**
      * Returns an InstructionContext[] with all the InstructionContext instances for the method whose control flow is
-     * represented by this ControlFlowGraph <B>(NOT ORDERED!)</B>.
+     * represented by this ControlFlowGraph <strong>(NOT ORDERED!)</strong>.
+     *
+     * @return array of InstructionContext instances.
      */
     public InstructionContext[] getInstructionContexts() {
         final InstructionContext[] ret = new InstructionContext[instructionContexts.size()];
@@ -429,6 +429,9 @@ public class ControlFlowGraph {
     /**
      * Returns true, if and only if the said instruction is not reachable; that means, if it is not part of this
      * ControlFlowGraph.
+     *
+     * @param i the instruction handle.
+     * @return true if the instruction is not reachable, false otherwise.
      */
     public boolean isDead(final InstructionHandle i) {
         return subroutines.subroutineOf(i) == null;
